Bifrost: src/ColoredCDBG.hpp File Reference

Bifrost

Data Structures
ColoredCDBG.hpp File Reference

Interface for the Colored and Compacted de Bruijn graph API. More...

Go to the source code of this file.

## Data Structures
struct | CCDBG_Build_opt
| This structure inherits from CDBG_Build_opt and introduces only a few new members which are color-related. More...
class | CCDBG_Data_t< Unitig_data_t >
| If data are to be associated with the unitigs of the colored and compacted de Bruijn graph, those data must be wrapped into a class that inherits from the abstract class CCDBG_Data_t. More...
class | ColoredCDBG< Unitig_data_t >
| Represent a Colored and Compacted de Bruijn graph. More...

## Detailed Description

Interface for the Colored and Compacted de Bruijn graph API.

Code snippets using this interface are provided in test/snippets.hpp.